@@ -99,10 +99,14 @@ def get_config(cli_context):
     }
     data = ChainMap(cli_values, config_values, defaults)
 
+    host = data['host']
+    if not host.startswith('http'):
+        host = ''.join(['http://', host])
+
     if 'port' in data:
-        data['url'] = ':'.join([data['host'], str(data['port'])])
+        data['url'] = ':'.join([host, str(data['port'])])
     else:
-        data['url'] = data['host']
+        data['url'] = host
 
     return data
 
@@ -228,7 +232,11 @@ def handle_request_with_token(
     if 'access_token' not in tokens:
         refresh_token(config_data)
     else:
-        access_token = jwt.decode(tokens['access_token'], verify=False)
+        access_token = jwt.decode(
+            tokens['access_token'],
+            verify=False,
+            options={'verify_signature': False}
+        )
         now = int(time.time())
 
         if access_token.get('exp') and now >= access_token['exp']:
